==> dklibs-1.23.1.tar.gz: dklibs-1.23.1/Java/TraceGUI/src/traceccgui/TraceccMainProgram.java <==
/*
Copyright (c) 2008, Dirk Krause
All rights reserved.

Redistribution and use in source and binary forms,
with or without modification, are permitted provided
that the following conditions are met:

* Redistributions of source code must retain the above
  copyright notice, this list of conditions and the
  following disclaimer.
* Redistributions in binary form must reproduce the above 
  opyright notice, this list of conditions and the following
  disclaimer in the documentation and/or other materials
  provided with the distribution.
* Neither the name of the Dirk Krause nor the names of
  its contributors may be used to endorse or promote
  products derived from this software without specific
  prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED.
IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
DAMAGE.
*/


package traceccgui;

import java.awt.SplashScreen;
import java.io.File;
import javax.swing.SwingUtilities;
import dirk_krause.jtools.GuiController;
import dirk_krause.jtools.PlatformInformation;
import dirk_krause.jtools.ComponentPositioner;

/**
 * The main program for the Tracecc GUI application.
 *
 * @author krause
 */
public class TraceccMainProgram {
    
    protected String w = null;

    /**
     * Runnable to be run in event processing thread to
     * build the GUI.
     */
    class GuiConstructor implements Runnable {
        /** Object controlling the tracecc options */
        private TraceccController tc = null;

	/** Object controlling GUI */
        private GuiController gc;

	/**
	 * Constructor.
	 *
	 * @param t
	 * New object for tc.
	 *
	 * @param g
	 * New object for gc.
	 */
        public GuiConstructor(TraceccController t, GuiController g) {
            tc = t; gc = g;
        }

	/**
	 * Go and create the GUI.
	 */
	@Override
        public void run() {
            TraceccMainWindow t = new TraceccMainWindow(tc, gc);
            t.restorePosition();
            ComponentPositioner.correctPosition(t);
	    try {
	      SplashScreen sso = SplashScreen.getSplashScreen();
	      if(sso != null) { sso.close(); }
	    } catch(Exception e) {}
            t.setVisible(true);
        }
    }
    

    /**
     * Empty constructor.
     */
    public TraceccMainProgram(String wd) {
      w = wd;
    }
    
    /**
     * Create the controllers and schedule the GUI creation in the
     * event processing thread.
     */
    public void run() {
        PlatformInformation pi = new PlatformInformation();
        pi.init();
        TraceccController tc = new TraceccController(pi);
        tc.init(); if(w != null) { tc.setString(0, w); }
        GuiController gc = new GuiController(TGS.lt[0]);
        gc.initialize();
        SwingUtilities.invokeLater(new GuiConstructor(tc, gc));
    }

    /**
     * The applications main program.
     *
     * @param args
     * The command line arguments, only one argument
     * (the directory to open, optional) is allowed.
     */
    public static void main(String[] args) {
        String wd = null;
	if(args.length > 0) {
	  try {
	    File f = new File(args[0]);
	    if(f.exists()) {
	      if(f.isDirectory()) {
	        wd = args[0];
	      }
	    }
	  } catch(Exception exc) {}
	}
        TraceccMainProgram m = new TraceccMainProgram(wd);
        m.run();
    }

}



// project tracegui
// @(#)TraceccMainProgram.java 1.5 07/21/08

==> dklibs-1.26.0.tar.gz: dklibs-1.26.0/Java/TraceGUI/src/traceccgui/TraceccMainProgram.java <==
/*
Copyright (c) 2008, Dirk Krause
All rights reserved.

Redistribution and use in source and binary forms,
with or without modification, are permitted provided
that the following conditions are met:

* Redistributions of source code must retain the above
  copyright notice, this list of conditions and the
  following disclaimer.
* Redistributions in binary form must reproduce the above 
  opyright notice, this list of conditions and the following
  disclaimer in the documentation and/or other materials
  provided with the distribution.
* Neither the name of the Dirk Krause nor the names of
  its contributors may be used to endorse or promote
  products derived from this software without specific
  prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED.
IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
DAMAGE.
*/


package traceccgui;

import java.awt.SplashScreen;
import java.io.File;
import javax.swing.SwingUtilities;
import dirk_krause.jtools.GuiController;
import dirk_krause.jtools.PlatformInformation;
import dirk_krause.jtools.ComponentPositioner;


// <editor-fold defaultstate="collapsed" desc="class GuiConstructor">
/**
 * Runnable to be run in event processing thread to
 * build the GUI.
 */
class GuiConstructor implements Runnable {

     /** Object controlling the tracecc options */
     private TraceccController tc = null;

    /**
     * Constructor.
     *
     * @param t
     * New object for tc.
     */
     public GuiConstructor(TraceccController t) {
         tc = t;
     }

    /**
     * Go and create the GUI.
     */
    @Override
    public void run() {
        GuiController gc = new GuiController(TGS.lt[0], true);
        gc.initialize();
        TraceccMainWindow t = new TraceccMainWindow(tc, gc);
        t.restorePosition();
        ComponentPositioner.correctPosition(t);
        try {
            SplashScreen sso = SplashScreen.getSplashScreen();
            if(sso != null) { sso.close(); }
        } catch(Exception e) {}
        t.setVisible(true);
    }
}
// </editor-fold>



/**
 * The main program for the Tracecc GUI application.
 *
 * @author krause
 */
public class TraceccMainProgram {
    
    /**
     * The applications main program.
     *
     * @param args
     * The command line arguments, only one argument
     * (the directory to open, optional) is allowed.
     */
    public static void main(String[] args) {
        String wd = null;
	if(args.length > 0) {
	  try {
	    File f = new File(args[0]);
	    if(f.exists()) {
	      if(f.isDirectory()) {
	        wd = args[0];
	      }
	    }
	  } catch(Exception exc) {}
	}
        // TraceccMainProgram m = new TraceccMainProgram(wd);
        // m.run();
	PlatformInformation pi = new PlatformInformation();
	pi.init();
	TraceccController tc = new TraceccController(pi);
	tc.init(); if(wd != null) { tc.setString(0, wd); }
	SwingUtilities.invokeLater(new GuiConstructor(tc));
    }

}



// project tracegui
// @(#)TraceccMainProgram.java 1.7 10/29/09
